@@ -20,10 +20,11 @@ returnRatings <- function(ratings, newdata,
 
   if(type=="ratingMatrix") {
     ### replace with known ratings. Removed. We return the approximation by the algorithm instead.
-    nm <- as(denormalize(newdata), "matrix")
-    rm <- as(ratings, "matrix")
-    rm[!is.na(nm)] <- nm[!is.na(nm)]
-    return(as(rm, "realRatingMatrix"))
+    #nm <- as(denormalize(newdata), "matrix")
+    #rm <- as(ratings, "matrix")
+    #rm[!is.na(nm)] <- nm[!is.na(nm)]
+    #return(as(rm, "realRatingMatrix"))
+    return(ratings)
   }
 
 
